coherence.backends.feed_storage (module) — Cohen3 0.8.0 documentation

# coherence.backends.feed_storage (module)

class `RedirectingReverseProxyUriResource`(uri, reactor=<twisted.internet.epollreactor.EPollReactor object>)

  Bases: `coherence.upnp.core.utils.ReverseProxyUriResource`

  `render`(request)

    Render a request by forwarding it to the proxied server.

  `follow_redirect`(uri)

exception `FeedStorageConfigurationException`

  Bases: `Exception`

class `FeedContainer`(parent_id, id, title)

  Bases: `coherence.backend.BackendItem`

  `get_children`(start=0, end=0)

    returns all the chidlren of this container

  `get_child_count`()

    returns the number of children in this container

class `FeedEnclosure`(store, parent, id, title, enclosure)

  Bases: `coherence.backend.BackendItem`

class `FeedStore`(server, **kwargs)

  Bases: `coherence.backend.BackendStore`

  a general feed store

  `logCategory` = 'feed_store'
  `implements` = ['MediaServer']
  `get_by_id`(id)

    returns the item according to the DIDLite id

  `_update_data`()

    get the feed xml, parse it, etc.